@@ -1,5 +1,5 @@
 /*
-  $Id: Instance.h 9072 2011-03-23 09:20:03Z sloot $
+  $Id: Instance.h 9981 2011-05-16 11:13:30Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Instance.h $
 
   Copyright (c) 1998 - 2011
@@ -104,6 +104,7 @@ namespace Timbl {
 							Target *, bool );
     const std::string DistToString() const;
     const std::string DistToStringW( int ) const;
+    double Confidence( const TargetValue * ) const;
     virtual const std::string ToEncodedString() const;
     virtual const std::string SaveHashed() const;
     virtual const std::string Save() const;
@@ -134,6 +135,7 @@ namespace Timbl {
     const std::string Save() const;
     void Normalize();
     void Normalize_1( double, const Target * );
+    void Normalize_2();
     void MergeW( const ValueDistribution&, double );
   private:
     void DistToEncodedString( std::string& ) const;
