@@ -1,5 +1,5 @@
 /*
-  $Id: TimblExperiment.h 12767 2011-08-01 09:52:00Z sloot $
+  $Id: TimblExperiment.h 13052 2011-08-31 14:01:14Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/TimblExperiment.h $
 
   Copyright (c) 1998 - 2011
@@ -57,6 +57,9 @@ namespace Timbl {
     std::string getResult();
     void prepare();
     void normalize();
+    double confidence( const TargetValue* tv ) const { 
+      return dist->Confidence( tv );
+    };
   private:
     const ValueDistribution *rawDist;
     WValueDistribution *dist;
@@ -201,6 +204,7 @@ namespace Timbl {
     bool learnFromFileIndex( const fileIndex&, std::istream& );
     bool initTestFiles( const std::string&, const std::string& );
     void show_results( std::ostream&,
+		       const double,
 		       const std::string&, 
 		       const TargetValue *,
 		       const double ) ;
