@@ -1,5 +1,5 @@
 /*
-  $Id: Types.h 9981 2011-05-16 11:13:30Z sloot $
+  $Id: Types.h 13052 2011-08-31 14:01:14Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Types.h $
 
   Copyright (c) 1998 - 2011
@@ -201,7 +201,7 @@ namespace Timbl {
 			VD_MATRIX=8, EXACT=16, DISTANCE=32, DISTRIB=64,
 			NEAR_N=128, ADVANCED_STATS=256, CONF_MATRIX=512,
 			CLASS_STATS=1024, CLIENTDEBUG=2048, ALL_K=4096,
-			MATCH_DEPTH=8192, BRANCHING=16384,
+			MATCH_DEPTH=8192, BRANCHING=16384, CONFIDENCE=32768,
                         MAX_VERB };
 
   inline VerbosityFlags operator~( VerbosityFlags V ){
