@@ -1,5 +1,5 @@
 /*
-  $Id: GetOptClass.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: GetOptClass.cxx 13135 2011-09-12 08:41:06Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/GetOptClass.cxx $
 
   Copyright (c) 1998 - 2011
@@ -304,6 +304,12 @@ namespace Timbl {
 	Exp->Estimate( 0 );
       else
 	Exp->Estimate( estimate );
+      if ( myVerbosity & CONFIDENCE ){
+	if ( local_normalisation == unknownNorm ){
+	  Error( "Invalid option +vcf, while -G is missing!" );
+	  return false;
+	}
+      }
       if ( myVerbosity & DISTRIB ){
 	if ( !keep_distributions && local_algo == IGTREE_a ){
 	  myVerbosity &= ~DISTRIB;
@@ -1113,29 +1119,33 @@ namespace Timbl {
 	      return false;
 	    }
 	  }
+	  else if ( long_option == "Treeorder" ){
+	    if ( !stringTo<OrdeningType>( myoptarg, local_order ) ){
+	      Error( "invalid value for Treeorder: " + myoptarg );
+	      return false;
+	    }
+	  }
 	  else {
-	    Error( "invalid option: Did you mean '--Threshold' ?" );
+	    Error( "invalid option: Did you mean '--Threshold' or --Treeorder ?" );
 	    return false;
 	  }
 	}
-	else if ( myoptarg.find("hreshold") != string::npos ){
+	else if ( myoptarg.find("hreshold") != string::npos ||
+		  myoptarg.find("reeorder") != string::npos ){
 	  Error( "invalid option: Did you mean '--T" + myoptarg + "' ?" );
 	  return false;
 	}
-	else if ( !stringTo<OrdeningType>( myoptarg, local_order ) ){
-	  local_order = UnknownOrdening;
-	  if ( ! stringTo<int>( myoptarg, target_pos ) ){
-	    Error( "invalid option: Did you mean '--Threshold' ?" );
-	    return false;
-	  }
-	  else if ( target_pos <= 0 ){
-	    Error( "illegal value for -T option: " + myoptarg );
-	    return false;
-	  }
+	else if ( ! stringTo<int>( myoptarg, target_pos ) ){
+	  Error( "invalid option: Did you mean '-T value ?" );
+	  return false;
+	}
+	else if ( target_pos <= 0 ){
+	  Error( "illegal value for -T option: " + myoptarg );
+	  return false;
 	}
       }
 	break;
-
+	
       case 'v':{
 	VerbosityFlags Flag = NO_VERB;
 	if ( !stringTo<VerbosityFlags>( myoptarg, Flag ) ){
