@@ -1,5 +1,5 @@
 /*
-  $Id: IBtree.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: IBtree.cxx 13733 2011-12-20 14:23:11Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/IBtree.cxx $
 
   Copyright (c) 1998 - 2011
@@ -1109,7 +1109,7 @@ namespace Timbl {
 
   TRIBL_InstanceBase *TRIBL_InstanceBase::Copy() const {
     TRIBL_InstanceBase *result = clone();
-    result->Treshold = Treshold;
+    result->Threshold = Threshold;
     result->DefAss = DefAss;
     result->DefaultsValid = DefaultsValid;
     result->NumOfTails = NumOfTails; // only usefull for Server???
@@ -1204,13 +1204,13 @@ namespace Timbl {
     DefaultsValid = true;
   }
 
-  void TRIBL_InstanceBase::AssignDefaults( size_t treshold ){
-    if ( Treshold != treshold ){
-      Treshold = treshold;
+  void TRIBL_InstanceBase::AssignDefaults( size_t threshold ){
+    if ( Threshold != threshold ){
+      Threshold = threshold;
       DefaultsValid = false;
     }
     if ( !DefaultsValid ){
-      InstBase->assign_defaults( Random, PersistentDistributions, Treshold );
+      InstBase->assign_defaults( Random, PersistentDistributions, Threshold );
     }
     DefAss = true;
     DefaultsValid = true;
@@ -1676,7 +1676,7 @@ namespace Timbl {
   }
 
   IB_InstanceBase *TRIBL_InstanceBase::TRIBL_test( const Instance& Inst, 
-						   size_t treshold,
+						   size_t threshold,
 						   const TargetValue *&TV,
 						   const ValueDistribution *&dist,
 						   size_t &level ) {
@@ -1685,12 +1685,12 @@ namespace Timbl {
     // or the subtree Instance Base necessary for IB1
     IBtree *pnt = InstBase;
 #pragma omp critical
-    AssignDefaults( treshold );
+    AssignDefaults( threshold );
     TV = NULL;
     dist = NULL;
     IB_InstanceBase *subt = NULL;
     size_t pos = 0;
-    while ( pnt && pos < treshold ){
+    while ( pnt && pos < threshold ){
       if ( pnt->FValue == Inst.FV[pos] ){
 	dist = pnt->TDistribution;
 	TV = pnt->TValue;
@@ -1704,7 +1704,7 @@ namespace Timbl {
       else
 	pnt = pnt->next;
     }
-    if ( pos == treshold ){
+    if ( pos == threshold ){
       if ( pnt ){
 	subt = IBPartition( pnt );
 	dist = NULL;
