@@ -1,5 +1,5 @@
 /*
-  $Id: Instance.cxx 12865 2011-08-11 14:39:27Z sloot $
+  $Id: Instance.cxx 13727 2011-12-20 11:51:57Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Instance.cxx $
 
   Copyright (c) 1998 - 2011
@@ -553,10 +553,8 @@ namespace Timbl {
 						    bool do_rand ) const {
     // get the most frequent target from the distribution.
     // In case of a tie take the one which is GLOBALLY the most frequent, 
-    // and signal if this ties also!
     // OR (if do_rand) take random one of the most frequents
-    // signal ties too. 
-    // BUT NOT for do_rand case! (see bug43)
+    // and signal if this ties also!
     const TargetValue *best = NULL;
     tie = false;
     VDlist::const_iterator It = distribution.begin();
@@ -577,7 +575,7 @@ namespace Timbl {
 	      nof_best++;
 	  ++It;
 	}
-	//	tie = ( nof_best > 1 );
+	tie = ( nof_best > 1 );
 	pick = random_number( 1, nof_best );
 	It = distribution.begin();
 	nof_best = 0;
@@ -620,10 +618,8 @@ namespace Timbl {
 						     bool do_rand ) const {
     // get the most frequent target from the distribution.
     // In case of a tie take the one which is GLOBALLY the most frequent, 
-    // and signal if this ties also!
     // OR (if do_rand) take random one of the most frequents
-    // signal ties too. 
-    // BUT NOT for do_rand case! (see bug43)
+    // and signal if this ties also!
     const TargetValue *best = NULL;
     VDlist::const_iterator It = distribution.begin();
     tie = false;
@@ -642,7 +638,7 @@ namespace Timbl {
 	      nof_best++;
 	  ++It;
 	}
-	//	tie = ( nof_best > 1 );
+	tie = ( nof_best > 1 );
 	pick = random_number( 1, nof_best );
 	It = distribution.begin();
 	nof_best = 0;
@@ -711,19 +707,10 @@ namespace Timbl {
   
   Feature& Feature::operator=( const Feature& in ){
     if ( this != &in ){
-      if ( in.PrestoreStatus == ps_read ){
-	metric_matrix = in.metric_matrix->copy();
-	metric = 0;
-	setMetricType( in.getMetricType() );
-	PrestoreStatus = in.PrestoreStatus;
-	Prestored_metric = in.Prestored_metric;
-      }
-      else {
-	metric_matrix = 0;
-	metric = 0;
-	PrestoreStatus = ps_undef;
-	Prestored_metric = UnknownMetric;
-      }
+      metric_matrix = in.metric_matrix;
+      metric = in.metric;
+      PrestoreStatus = in.PrestoreStatus;
+      Prestored_metric = in.Prestored_metric;
       ignore = in.ignore;
       numeric = in.numeric;
       vcpb_read = in.vcpb_read;
@@ -1456,9 +1443,9 @@ namespace Timbl {
 	delete [] n_dot_j;
 	delete [] n_i_dot;
       }
+      delete_matrix();
+      delete metric; 
     }
-    delete_matrix();
-    delete metric; 
   }
 
   bool Feature::matrixPresent( bool& isRead ) const {
