@@ -1,5 +1,5 @@
 /*
-  $Id: LOOExperiment.cxx 10513 2011-06-10 11:08:47Z sloot $
+  $Id: LOOExperiment.cxx 13052 2011-08-31 14:01:14Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/LOOExperiment.cxx $
 
   Copyright (c) 1998 - 2011
@@ -144,8 +144,12 @@ namespace Timbl {
 							   exact );
 	  normalizeResult();
 	  string dString = bestResult.getResult();
+	  double confidence = 0;
+	  if ( Verbosity(CONFIDENCE) )
+	    confidence = bestResult.confidence( ResultTarget );
 	  // Write it to the output file for later analysis.
-	  show_results( outStream, dString, ResultTarget, final_distance );
+	  show_results( outStream, confidence, dString, 
+			ResultTarget, final_distance );
 	  if ( exact ){ // remember that a perfect match may be incorrect!
 	    if ( Verbosity(EXACT) ) {
 	      *mylog << "Exacte match:\n" << get_org_input() << endl;
