@@ -1,5 +1,5 @@
 /*
-  $Id: TRIBLExperiments.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: TRIBLExperiments.cxx 13733 2011-12-20 14:23:11Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/TRIBLExperiments.cxx $
 
   Copyright (c) 1998 - 2011
@@ -84,7 +84,7 @@ namespace Timbl {
       return false;
     }
     else if ( TRIBL_offset() == 0 ){
-      Error( "TRIBL algorithm impossible while treshold not set\n" );
+      Error( "TRIBL algorithm impossible while threshold not set\n" );
       return false;
     }
     return true;
