@@ -1,5 +1,5 @@
 /*
-  $Id: Timbl.cxx 12969 2011-08-24 14:00:22Z sloot $
+  $Id: Timbl.cxx 13733 2011-12-20 14:23:11Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Timbl.cxx $
 
   Copyright (c) 1998 - 2011
@@ -128,8 +128,8 @@ inline void usage_full(void){
   cerr << "     ED:a:b : Exponential Decay with factor a and b (no whitespace!)"
        << endl;
   cerr << "-k n      : k nearest neighbors (default n = 1)" << endl;
-  cerr << "-q n      : TRIBL treshold at level n" << endl;
-  cerr << "-L n      : MVDM treshold at level n" << endl;
+  cerr << "-q n      : TRIBL threshold at level n" << endl;
+  cerr << "-L n      : MVDM threshold at level n" << endl;
   cerr << "-R n      : solve ties at random with seed n" << endl;
   cerr << "-t  f     : test using file 'f'" << endl;
   cerr << "-t leave_one_out:"
@@ -183,6 +183,7 @@ inline void usage_full(void){
   cerr << "      as: show advanced statistics (memory consuming)" << endl;
   cerr << "      cm: show Confusion Matrix (implies +vas)" << endl;
   cerr << "      cs: show per Class Statistics (implies +vas)" << endl;
+  cerr << "      cf: add confidence to the output file. (needs -G)" << endl;
   cerr << "      di: add distance to output file" << endl;
   cerr << "      db: add distribution of best matched to output file" 
        << endl;
@@ -218,7 +219,7 @@ inline void usage_full(void){
   cerr << "-M n      : size of MaxBests Array" << endl;
   cerr << "-N n      : Number of features (default " 
        << TimblAPI::Default_Max_Feats() << ")" << endl;
-  cerr << "-T n      : ordering of the Tree :" << endl;
+  cerr << "--Treeorder=<value>      : ordering of the Tree :" << endl;
   cerr << "       DO: none" << endl;
   cerr << "       GRO: using GainRatio" << endl;
   cerr << "       IGO: using InformationGain" << endl;
